import torch
from packaging import version

if version.parse(torch.__version__) >= version.parse('2.0.0'):
    from einops._torch_specific import allow_ops_in_compiled_graph
    allow_ops_in_compiled_graph()

from optimus_prime.x_transformers import XTransformer, Encoder, Decoder, CrossAttender, Attention, TransformerWrapper, ViTransformerWrapper, ContinuousTransformerWrapper
from optimus_prime.x_transformers import AndromedaEmbedding

# d
from optimus_prime.autoregressive_wrapper import AutoregressiveWrapper
from optimus_prime.nonautoregressive_wrapper import NonAutoregressiveWrapper
from optimus_prime.continuous_autoregressive_wrapper import ContinuousAutoregressiveWrapper
from optimus_prime.xl_autoregressive_wrapper import XLAutoregressiveWrapper




from optimus_prime import TransformerWrapper, AutoregressiveWrapper, AndromedaEmbedding, Decoder

Andromeda = TransformerWrapper(
    num_tokens=64007,
    max_seq_len=8192,
    use_abs_pos_emb=False,
    # tokenizer=tokenizer,
    embedding_provider=AndromedaEmbedding(),
    attn_layers = Decoder(
        dim=2560, # 2048
        depth=32, # 16
        dim_head=128,
        heads=24,
        alibi_pos_bias=True,
        alibi_num_heads=12,
        rotary_xpos=True,
        attn_flash = True,
        deepnorm=True,
        shift_tokens=1,
        attn_one_kv_head = True,
        qk_norm=True,
        attn_qk_norm=True,
        attn_qk_norm_dim_scale=True # set this to True, in addition to `attn_qk_norm = True`
    )
)

Andromeda = AutoregressiveWrapper(Andromeda)


from setuptools import setup, find_packages

setup(
  name = 'Andromeda-llm',
  packages = find_packages(exclude=['examples']),
  version = '0.0.3',
  license='MIT',
  description = 'andromeda - Pytorch',
  author = 'Kye Gomez',
  author_email = 'kye@apac.ai',
  url = 'https://github.com/kyegomez/Andromeda',
  long_description_content_type = 'text/markdown',
  keywords = [
    'artificial intelligence',
    'attention mechanism',
    'transformers'
  ],
  install_requires=[
    "torch"
    "lion-pytorch",
    "numpy",
    # colt5_attention
    "einops",
    # local_attention
    "accelerate",
    "transformers",
    # triton
    "SentencePiece",
    "bitsandbytes",
    "datasets",
    "Triton",
    "deepspeed"
  ],
  classifiers=[
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'Topic :: Scientific/Engineering :: Artificial Intelligence',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.6',
  ],
)